from setuptools import setup

setup(
    name='LGNB',
    version='0.8.1',
    author='wangcc',
    author_email='705190651@qq.com',
    url='https://oa.csc.com.cn',
    description=r'data api',
    packages=['BBData'],
)